pire
====

Python Interactive Regular Expression

Installation
------------

From the project root directory::

    $ python setup.py install

Or through PyPI:

    $ pip install pire

Usage
-----

Use --help/-h to view info on the arguments::

    $ pire --help

Releases
--------

| Version | Notes           |
| ------- | --------------- |
|  0.0.1  | Project created |
